@@ -1,6 +1,8 @@
 import asyncio
+import contextvars
 import functools
 import inspect
+import sys
 from typing import Any
 from typing import Callable
 from typing import cast
@@ -14,6 +16,17 @@ from loguru import logger
 from aflowey.f import F
 from aflowey.types import Function
 
+major, minor, *_ = sys.version_info
+if minor < 9:
+
+    async def to_thread(func, *args, **kwargs):
+        loop = asyncio.get_running_loop()
+        ctx = contextvars.copy_context()
+        func_call = functools.partial(ctx.run, func, *args, **kwargs)
+        return await loop.run_in_executor(None, func_call)
+
+    asyncio.to_thread = to_thread
+
 
 def async_wrap(func: Function) -> F:
     """wrap a function into a coroutine function
